#!/bin/sh

SNORT_INLINE=`grep "snort-inline=" /etc/packetprotector.conf | cut -d "=" -f 2`

if [ "X$SNORT_INLINE" = "X1" ] ; then
	
	echo "Snort-inline enabled.  Continuing..."

	if [ -s /packetprotector/etc/snort/oinkcode ] ; then

		echo "Oinkcode found!"

		OINKCODE=`cat /packetprotector/etc/snort/oinkcode | sed s/" "/""/g`
		export LD_LIBRARY_PATH=/packetprotector/usr/lib

		backdoor_rule_count=200
		web_client_rule_count=250

		echo "Fetching VRT rules!"

		VRT_RULES=http://www.snort.org/pub-bin/oinkmaster.cgi/$OINKCODE/snortrules-snapshot-CURRENT.tar.gz

		mkdir /packetprotector/tmp/oink
		cd /packetprotector/tmp/oink

		wget $VRT_RULES || exit
		tar -zxvf snortrules-snapshot-CURRENT.tar.gz rules/* > /dev/null 2> /dev/null
		echo "Rules extracted!"

		if [ -s snortrules-snapshot-CURRENT.tar.gz ] ; then
			cd rules
			cp /packetprotector/etc/snort/snort-inline.conf .
			mkdir drop-rules

			cp VRT-License.txt drop-rules/

			### setup backdoor rules
			grep -e "^alert" backdoor.rules | tail -$backdoor_rule_count | sed "s/^alert/drop/"  > drop-rules/backdoor.rules
			grep "include \$RULE_PATH/backdoor.rules" snort-inline.conf > /dev/null
			if [ $? = 0 ] ; then
				echo "backdoor.rules found in snort-inline.conf"
			else
				echo "include \$RULE_PATH/backdoor.rules" >> snort-inline.conf
			fi

			### setup web-client rules
			grep -e "^alert" web-client.rules | tail -$web_client_rule_count | sed "s/^alert/drop/"  > drop-rules/web-client.rules
			grep "include \$RULE_PATH/web-client.rules" snort-inline.conf > /dev/null
			if [ $? = 0 ] ; then
				echo "web-client.rules found in snort-inline.conf"
			else
				echo "include \$RULE_PATH/web-client.rules" >> snort-inline.conf
			fi

			### copy to /packetprotector/etc/snort/drop-rules
			rm -rf /packetprotector/etc/snort/drop-rules.OLD
			rm -f /packetprotector/etc/snort/snort-inline.conf.OLD
			cp -r /packetprotector/etc/snort/drop-rules /packetprotector/etc/snort/drop-rules.OLD
			cp /packetprotector/etc/snort/snort-inline.conf /packetprotector/etc/snort/snort-inline.conf.OLD
			cp drop-rules/* /packetprotector/etc/snort/drop-rules
			cp snort-inline.conf /packetprotector/etc/snort/

			### test new rules
			/packetprotector/usr/sbin/snort-inline -QT -c /packetprotector/etc/snort/snort-inline.conf > /dev/null 2> /dev/null

			if [ $? = 0 ]; then
				echo "Snort test succeeded!  Rotating alert file and restarting Snort."
				EPOCHTIME=`date +%s`
				LOGDIR="/var/log"
				mv $LOGDIR/snort-inline/alert $LOGDIR/snort-inline/alert.$EPOCHTIME && touch $LOGDIR/snort-inline/alert
				# restart
				killall snort-inline
				echo "Snort killed!"
				sleep 3
				echo "Restarting Snort!"
				/packetprotector/etc/init.d/S11snort-inline
				echo "Done!"
				# update timestamp
				date "+%a %b %d %H:%M:%S %Y" > /packetprotector/etc/snort/drop-rules/last_updated
			else
				echo "Snort test failed!  Restoring old signatures."
				rm -rf /packetprotector/etc/snort/drop-rules
				rm -f /packetprotector/etc/snort/snort-inline.conf
				mv /packetprotector/etc/snort/drop-rules.OLD /packetprotector/etc/snort/drop-rules
				mv /packetprotector/etc/snort/snort-inline.conf.OLD /packetprotector/etc/snort/snort-inline.conf
			fi
		
		else
 			echo "Error fetching rules files!"

		fi

		cd
		rm -rf /packetprotector/tmp/oink

	else
		echo "Oinkcode not found!"

	fi

fi
